@@ -16,47 +16,55 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
 
 """Init the Glances software."""
 
-__appname__ = 'glances'
-__version__ = '2.3'
-__author__ = 'Nicolas Hennion <nicolas@nicolargo.com>'
-__license__ = 'LGPL'
-
-# Import system lib
-import gettext
 import locale
 import platform
 import signal
 import sys
 
+# Global name
+__appname__ = 'glances'
+__version__ = '2.6.2'
+__author__ = 'Nicolas Hennion <nicolas@nicolargo.com>'
+__license__ = 'LGPL'
+
 # Import psutil
 try:
-    from psutil import __version__ as __psutil_version
+    from psutil import __version__ as psutil_version
 except ImportError:
     print('PSutil library not found. Glances cannot start.')
     sys.exit(1)
 
 # Import Glances libs
 # Note: others Glances libs will be imported optionally
-from glances.core.glances_globals import gettext_domain, locale_dir
-from glances.core.glances_logging import logger
-from glances.core.glances_main import GlancesMain
+from glances.logger import logger
+from glances.main import GlancesMain
 
-# Get PSutil version
-psutil_min_version = (2, 0, 0)
-psutil_version = tuple([int(num) for num in __psutil_version.split('.')])
+try:
+    locale.setlocale(locale.LC_ALL, '')
+except locale.Error:
+    print("Warning: Unable to set locale. Expect encoding problems.")
 
-# First log with Glances and PSUtil version
-logger.info('Start Glances {0}'.format(__version__))
-logger.info('{0} {1} and PSutil {2} detected'.format(platform.python_implementation(),
-                                                     platform.python_version(),
-                                                     __psutil_version))
+# Check Python version
+if sys.version_info < (2, 6) or (3, 0) <= sys.version_info < (3, 3):
+    print('Glances requires at least Python 2.6 or 3.3 to run.')
+    sys.exit(1)
+
+if sys.version_info[:2] == (2, 6):
+    import warnings
+    warnings.warn('Python 2.6 support will be dropped. Please switch '
+                  'to at least Python 2.7 or 3.3+ as soon as possible. '
+                  'See http://www.snarky.ca/stop-using-python-2-6 '
+                  'for more information.')
 
 # Check PSutil version
-if psutil_version < psutil_min_version:
-    logger.critical('PSutil 2.0 or higher is needed. Glances cannot start.')
+psutil_min_version = (2, 0, 0)
+psutil_version_info = tuple([int(num) for num in psutil_version.split('.')])
+if psutil_version_info < psutil_min_version:
+    print('PSutil 2.0 or higher is needed. Glances cannot start.')
     sys.exit(1)
 
 
@@ -94,9 +102,12 @@ def main():
     Select the mode (standalone, client or server)
     Run it...
     """
-    # Setup translations
-    locale.setlocale(locale.LC_ALL, '')
-    gettext.install(gettext_domain, locale_dir)
+    # Log Glances and PSutil version
+    logger.info('Start Glances {0}'.format(__version__))
+    logger.info('{0} {1} and PSutil {2} detected'.format(
+        platform.python_implementation(),
+        platform.python_version(),
+        psutil_version))
 
     # Share global var
     global core, standalone, client, server, webserver
@@ -112,7 +123,7 @@ def main():
         logger.info("Start standalone mode")
 
         # Import the Glances standalone module
-        from glances.core.glances_standalone import GlancesStandalone
+        from glances.standalone import GlancesStandalone
 
         # Init the standalone mode
         standalone = GlancesStandalone(config=core.get_config(),
@@ -126,7 +137,7 @@ def main():
             logger.info("Start client mode (browser)")
 
             # Import the Glances client browser module
-            from glances.core.glances_client_browser import GlancesClientBrowser
+            from glances.client_browser import GlancesClientBrowser
 
             # Init the client
             client = GlancesClientBrowser(config=core.get_config(),
@@ -136,7 +147,7 @@ def main():
             logger.info("Start client mode")
 
             # Import the Glances client module
-            from glances.core.glances_client import GlancesClient
+            from glances.client import GlancesClient
 
             # Init the client
             client = GlancesClient(config=core.get_config(),
@@ -157,14 +168,14 @@ def main():
         logger.info("Start server mode")
 
         # Import the Glances server module
-        from glances.core.glances_server import GlancesServer
+        from glances.server import GlancesServer
 
         args = core.get_args()
 
         server = GlancesServer(cached_time=core.cached_time,
                                config=core.get_config(),
                                args=args)
-        print(_("Glances server is running on {0}:{1}").format(args.bind_address, args.port))
+        print('Glances server is running on {0}:{1}'.format(args.bind_address, args.port))
 
         # Set the server login/password (if -P/--password tag)
         if args.password != "":
@@ -180,7 +191,7 @@ def main():
         logger.info("Start web server mode")
 
         # Import the Glances web server module
-        from glances.core.glances_webserver import GlancesWebServer
+        from glances.webserver import GlancesWebServer
 
         # Init the web server mode
         webserver = GlancesWebServer(config=core.get_config(),
