@@ -3,7 +3,7 @@
 #
 # Glances - An eye on your system
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -20,50 +20,34 @@
 
 """Glances unitary tests suite."""
 
-import gettext
-import locale
 import sys
 import time
 import unittest
 
-from glances.core.glances_globals import (
-    appname,
-    is_linux,
-    version
-)
-
 # Global variables
 # =================
 
-# Unitary test is only available from a GNU/Linus machine
-if not is_linux:
-    print('ERROR: Unitaries tests should be ran on GNU/Linux operating system')
-    sys.exit(2)
-else:
-    print('Unitary tests for {0} {1}'.format(appname, version))
-
-# Import local settings
-from glances.core.glances_globals import gettext_domain, locale_dir
-locale.setlocale(locale.LC_ALL, '')
-gettext.install(gettext_domain, locale_dir)
-
 # Init Glances core
-from glances.core.glances_main import GlancesMain
+from glances.main import GlancesMain
 core = GlancesMain()
 if not core.is_standalone():
     print('ERROR: Glances core should be ran in standalone mode')
     sys.exit(1)
 
 # Init Glances stats
-from glances.core.glances_stats import GlancesStats
+from glances.stats import GlancesStats
 stats = GlancesStats()
 
+from glances import __version__
+from glances.globals import WINDOWS
+from glances.outputs.glances_bars import Bar
 
 # Unitest class
 # ==============
+print('Unitary tests for Glances %s' % __version__)
+
 
 class TestGlances(unittest.TestCase):
-
     """Test Glances class."""
 
     def setUp(self):
@@ -78,14 +62,14 @@ class TestGlances(unittest.TestCase):
         print('INFO: [TEST_000] Test the stats update function')
         try:
             stats.update()
-        except:
-            print('ERROR: Stats update failed')
+        except Exception as e:
+            print('ERROR: Stats update failed: %s' % e)
             self.assertTrue(False)
         time.sleep(1)
         try:
             stats.update()
-        except:
-            print('ERROR: Stats update failed')
+        except Exception as e:
+            print('ERROR: Stats update failed: %s' % e)
             self.assertTrue(False)
 
         self.assertTrue(True)
@@ -121,6 +105,7 @@ class TestGlances(unittest.TestCase):
             self.assertLessEqual(stats_grab[stat], 100)
         print('INFO: CPU stats: %s' % stats_grab)
 
+    @unittest.skipIf(WINDOWS, "Load average not available on Windows")
     def test_004_load(self):
         """Check LOAD plugin."""
         stats_to_check = ['cpucore', 'min1', 'min5', 'min15']
@@ -166,7 +151,7 @@ class TestGlances(unittest.TestCase):
 
     def test_008_diskio(self):
         """Check DISKIO plugin."""
-        print('INFO: [TEST_008] Check DiskIO stats')
+        print('INFO: [TEST_008] Check DISKIO stats')
         stats_grab = stats.get_plugin('diskio').get_raw()
         self.assertTrue(type(stats_grab) is list, msg='DiskIO stats is not a list')
         print('INFO: diskio stats: %s' % stats_grab)
@@ -193,5 +178,41 @@ class TestGlances(unittest.TestCase):
         # Check if number of processes in the list equal counter
         # self.assertEqual(total, len(stats_grab))
 
+    def test_011_folders(self):
+        """Check File System plugin."""
+        # stats_to_check = [ ]
+        print('INFO: [TEST_011] Check FOLDER stats')
+        stats_grab = stats.get_plugin('folders').get_raw()
+        self.assertTrue(type(stats_grab) is list, msg='Folders stats is not a list')
+        print('INFO: Folders stats: %s' % stats_grab)
+
+    def test_012_ip(self):
+        """Check IP plugin."""
+        print('INFO: [TEST_012] Check IP stats')
+        stats_grab = stats.get_plugin('ip').get_raw()
+        self.assertTrue(type(stats_grab) is dict, msg='IP stats is not a dict')
+        print('INFO: IP stats: %s' % stats_grab)
+
+    def test_099_output_bars_must_be_between_0_and_100_percent(self):
+        """Test quick look plugin.
+
+        > bar.min_value
+        0
+        > bar.max_value
+        100
+        > bar.percent = -1
+        > bar.percent
+        0
+        > bar.percent = 101
+        > bar.percent
+        100
+        """
+        print('INFO: [TEST_011] Test progress bar')
+        bar = Bar(size=1)
+        bar.percent = -1
+        self.assertLessEqual(bar.percent, bar.min_value)
+        bar.percent = 101
+        self.assertGreaterEqual(bar.percent, bar.max_value)
+
 if __name__ == '__main__':
     unittest.main()
